# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SageMaker'
prefix = 'sagemaker'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
AssociateTrialComponent = Action('AssociateTrialComponent')
BatchGetMetrics = Action('BatchGetMetrics')
BatchPutMetrics = Action('BatchPutMetrics')
CreateAlgorithm = Action('CreateAlgorithm')
CreateApp = Action('CreateApp')
CreateAutoMLJob = Action('CreateAutoMLJob')
CreateCodeRepository = Action('CreateCodeRepository')
CreateCompilationJob = Action('CreateCompilationJob')
CreateDomain = Action('CreateDomain')
CreateEndpoint = Action('CreateEndpoint')
CreateEndpointConfig = Action('CreateEndpointConfig')
CreateExperiment = Action('CreateExperiment')
CreateFlowDefinition = Action('CreateFlowDefinition')
CreateHumanTaskUi = Action('CreateHumanTaskUi')
CreateHyperParameterTuningJob = Action('CreateHyperParameterTuningJob')
CreateLabelingJob = Action('CreateLabelingJob')
CreateModel = Action('CreateModel')
CreateModelPackage = Action('CreateModelPackage')
CreateMonitoringSchedule = Action('CreateMonitoringSchedule')
CreateNotebookInstance = Action('CreateNotebookInstance')
CreateNotebookInstanceLifecycleConfig = \
    Action('CreateNotebookInstanceLifecycleConfig')
CreatePresignedDomainUrl = Action('CreatePresignedDomainUrl')
CreatePresignedNotebookInstanceUrl = \
    Action('CreatePresignedNotebookInstanceUrl')
CreateProcessingJob = Action('CreateProcessingJob')
CreateTrainingJob = Action('CreateTrainingJob')
CreateTransformJob = Action('CreateTransformJob')
CreateTrial = Action('CreateTrial')
CreateTrialComponent = Action('CreateTrialComponent')
CreateUserProfile = Action('CreateUserProfile')
CreateWorkforce = Action('CreateWorkforce')
CreateWorkteam = Action('CreateWorkteam')
DeleteAlgorithm = Action('DeleteAlgorithm')
DeleteApp = Action('DeleteApp')
DeleteCodeRepository = Action('DeleteCodeRepository')
DeleteDomain = Action('DeleteDomain')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteEndpointConfig = Action('DeleteEndpointConfig')
DeleteExperiment = Action('DeleteExperiment')
DeleteFlowDefinition = Action('DeleteFlowDefinition')
DeleteHumanLoop = Action('DeleteHumanLoop')
DeleteModel = Action('DeleteModel')
DeleteModelPackage = Action('DeleteModelPackage')
DeleteMonitoringSchedule = Action('DeleteMonitoringSchedule')
DeleteNotebookInstance = Action('DeleteNotebookInstance')
DeleteNotebookInstanceLifecycleConfig = \
    Action('DeleteNotebookInstanceLifecycleConfig')
DeleteTags = Action('DeleteTags')
DeleteTrial = Action('DeleteTrial')
DeleteTrialComponent = Action('DeleteTrialComponent')
DeleteUserProfile = Action('DeleteUserProfile')
DeleteWorkforce = Action('DeleteWorkforce')
DeleteWorkteam = Action('DeleteWorkteam')
DescribeAlgorithm = Action('DescribeAlgorithm')
DescribeApp = Action('DescribeApp')
DescribeAutoMLJob = Action('DescribeAutoMLJob')
DescribeCodeRepository = Action('DescribeCodeRepository')
DescribeCompilationJob = Action('DescribeCompilationJob')
DescribeDomain = Action('DescribeDomain')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeEndpointConfig = Action('DescribeEndpointConfig')
DescribeExperiment = Action('DescribeExperiment')
DescribeFlowDefinition = Action('DescribeFlowDefinition')
DescribeHumanLoop = Action('DescribeHumanLoop')
DescribeHumanTaskUi = Action('DescribeHumanTaskUi')
DescribeHyperParameterTuningJob = \
    Action('DescribeHyperParameterTuningJob')
DescribeLabelingJob = Action('DescribeLabelingJob')
DescribeModel = Action('DescribeModel')
DescribeModelPackage = Action('DescribeModelPackage')
DescribeMonitoringSchedule = Action('DescribeMonitoringSchedule')
DescribeNotebookInstance = Action('DescribeNotebookInstance')
DescribeNotebookInstanceLifecycleConfig = \
    Action('DescribeNotebookInstanceLifecycleConfig')
DescribeProcessingJob = Action('DescribeProcessingJob')
DescribeSubscribedWorkteam = Action('DescribeSubscribedWorkteam')
DescribeTrainingJob = Action('DescribeTrainingJob')
DescribeTransformJob = Action('DescribeTransformJob')
DescribeTrial = Action('DescribeTrial')
DescribeTrialComponent = Action('DescribeTrialComponent')
DescribeUserProfile = Action('DescribeUserProfile')
DescribeWorkforce = Action('DescribeWorkforce')
DescribeWorkteam = Action('DescribeWorkteam')
DisassociateTrialComponent = Action('DisassociateTrialComponent')
GetSearchSuggestions = Action('GetSearchSuggestions')
InvokeEndpoint = Action('InvokeEndpoint')
ListAlgorithms = Action('ListAlgorithms')
ListApps = Action('ListApps')
ListAutoMLJobs = Action('ListAutoMLJobs')
ListCandidatesForAutoMLJob = Action('ListCandidatesForAutoMLJob')
ListCodeRepositories = Action('ListCodeRepositories')
ListCompilationJobs = Action('ListCompilationJobs')
ListDomains = Action('ListDomains')
ListEndpointConfigs = Action('ListEndpointConfigs')
ListEndpoints = Action('ListEndpoints')
ListExperiments = Action('ListExperiments')
ListFlowDefinitions = Action('ListFlowDefinitions')
ListHumanLoops = Action('ListHumanLoops')
ListHumanTaskUis = Action('ListHumanTaskUis')
ListHyperParameterTuningJobs = Action('ListHyperParameterTuningJobs')
ListLabelingJobs = Action('ListLabelingJobs')
ListLabelingJobsForWorkteam = Action('ListLabelingJobsForWorkteam')
ListModelPackages = Action('ListModelPackages')
ListModels = Action('ListModels')
ListMonitoringExecutions = Action('ListMonitoringExecutions')
ListMonitoringSchedules = Action('ListMonitoringSchedules')
ListNotebookInstanceLifecycleConfigs = \
    Action('ListNotebookInstanceLifecycleConfigs')
ListNotebookInstances = Action('ListNotebookInstances')
ListProcessingJobs = Action('ListProcessingJobs')
ListSubscribedWorkteams = Action('ListSubscribedWorkteams')
ListTags = Action('ListTags')
ListTrainingJobs = Action('ListTrainingJobs')
ListTrainingJobsForHyperParameterTuningJob = \
    Action('ListTrainingJobsForHyperParameterTuningJob')
ListTransformJobs = Action('ListTransformJobs')
ListTrialComponents = Action('ListTrialComponents')
ListTrials = Action('ListTrials')
ListUserProfiles = Action('ListUserProfiles')
ListWorkforces = Action('ListWorkforces')
ListWorkteams = Action('ListWorkteams')
RenderUiTemplate = Action('RenderUiTemplate')
Search = Action('Search')
StartHumanLoop = Action('StartHumanLoop')
StartMonitoringSchedule = Action('StartMonitoringSchedule')
StartNotebookInstance = Action('StartNotebookInstance')
StopAutoMLJob = Action('StopAutoMLJob')
StopCompilationJob = Action('StopCompilationJob')
StopHumanLoop = Action('StopHumanLoop')
StopHyperParameterTuningJob = Action('StopHyperParameterTuningJob')
StopLabelingJob = Action('StopLabelingJob')
StopMonitoringSchedule = Action('StopMonitoringSchedule')
StopNotebookInstance = Action('StopNotebookInstance')
StopProcessingJob = Action('StopProcessingJob')
StopTrainingJob = Action('StopTrainingJob')
StopTransformJob = Action('StopTransformJob')
UpdateCodeRepository = Action('UpdateCodeRepository')
UpdateDomain = Action('UpdateDomain')
UpdateEndpoint = Action('UpdateEndpoint')
UpdateEndpointWeightsAndCapacities = \
    Action('UpdateEndpointWeightsAndCapacities')
UpdateExperiment = Action('UpdateExperiment')
UpdateMonitoringSchedule = Action('UpdateMonitoringSchedule')
UpdateNotebookInstance = Action('UpdateNotebookInstance')
UpdateNotebookInstanceLifecycleConfig = \
    Action('UpdateNotebookInstanceLifecycleConfig')
UpdateTrial = Action('UpdateTrial')
UpdateTrialComponent = Action('UpdateTrialComponent')
UpdateUserProfile = Action('UpdateUserProfile')
UpdateWorkforce = Action('UpdateWorkforce')
UpdateWorkteam = Action('UpdateWorkteam')
